==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/InboundProvisioningApplicationFeature.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ApplicationFeature;
import com.okta.sdk.resource.model.ApplicationFeatureLinks;
import com.okta.sdk.resource.model.ApplicationFeatureType;
import com.okta.sdk.resource.model.CapabilitiesInboundProvisioningObject;
import com.okta.sdk.resource.model.EnabledStatus;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * InboundProvisioningApplicationFeature
 */
@JsonPropertyOrder({ InboundProvisioningApplicationFeature.JSON_PROPERTY_CAPABILITIES })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "name", visible = true, defaultImpl = InboundProvisioningApplicationFeature.class)

public class InboundProvisioningApplicationFeature extends ApplicationFeature implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CAPABILITIES = "capabilities";
    private CapabilitiesInboundProvisioningObject capabilities;

    public InboundProvisioningApplicationFeature() {
    }

    /*
     * @JsonCreator public InboundProvisioningApplicationFeature(
     *
     * @JsonProperty(JSON_PROPERTY_DESCRIPTION) String description ) { this(); this.description = description; }
     */

    public InboundProvisioningApplicationFeature capabilities(CapabilitiesInboundProvisioningObject capabilities) {

        this.capabilities = capabilities;
        return this;
    }

    /**
     * Get capabilities
     *
     * @return capabilities
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CAPABILITIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CapabilitiesInboundProvisioningObject getCapabilities() {
        return capabilities;
    }

    @JsonProperty(JSON_PROPERTY_CAPABILITIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCapabilities(CapabilitiesInboundProvisioningObject capabilities) {
        this.capabilities = capabilities;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InboundProvisioningApplicationFeature inboundProvisioningApplicationFeature = (InboundProvisioningApplicationFeature) o;
        return Objects.equals(this.capabilities, inboundProvisioningApplicationFeature.capabilities);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(capabilities, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class InboundProvisioningApplicationFeature {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    capabilities: ").append(toIndentedString(capabilities)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/InboundProvisioningApplicationFeature.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ApplicationFeature;
import com.okta.sdk.resource.model.ApplicationFeatureLinks;
import com.okta.sdk.resource.model.ApplicationFeatureType;
import com.okta.sdk.resource.model.CapabilitiesInboundProvisioningObject;
import com.okta.sdk.resource.model.EnabledStatus;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * InboundProvisioningApplicationFeature
 */
@JsonPropertyOrder({ InboundProvisioningApplicationFeature.JSON_PROPERTY_CAPABILITIES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "name", visible = true, defaultImpl = InboundProvisioningApplicationFeature.class)

public class InboundProvisioningApplicationFeature extends ApplicationFeature implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CAPABILITIES = "capabilities";
    private CapabilitiesInboundProvisioningObject capabilities;

    public InboundProvisioningApplicationFeature() {
    }

    /*
     * @JsonCreator public InboundProvisioningApplicationFeature(
     *
     * @JsonProperty(JSON_PROPERTY_DESCRIPTION) String description ) { this(); this.description = description; }
     */

    public InboundProvisioningApplicationFeature capabilities(CapabilitiesInboundProvisioningObject capabilities) {

        this.capabilities = capabilities;
        return this;
    }

    /**
     * Get capabilities
     *
     * @return capabilities
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CAPABILITIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CapabilitiesInboundProvisioningObject getCapabilities() {
        return capabilities;
    }

    @JsonProperty(JSON_PROPERTY_CAPABILITIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCapabilities(CapabilitiesInboundProvisioningObject capabilities) {
        this.capabilities = capabilities;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InboundProvisioningApplicationFeature inboundProvisioningApplicationFeature = (InboundProvisioningApplicationFeature) o;
        return Objects.equals(this.capabilities, inboundProvisioningApplicationFeature.capabilities);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(capabilities, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class InboundProvisioningApplicationFeature {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    capabilities: ").append(toIndentedString(capabilities)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
